An R6 class that represents the 'keys' schema for CAS storage and provides active fields to get/set filter lists for each dimension/attribute.
This class should not be used directly, but it can be accessed via driver_schemas().
Super class
SchemaBase -> SchemaKeys
Active bindings
dim_namespaceGet or set a filter list.
dim_keyGet or set a filter list.
attr_hashGet or set a filter list.
attr_expires_atGet or set a filter list.
attr_notesGet or set a filter list.
Methods
Inherited methods
SchemaKeys$new()
Create a new SchemaKeys object.
Usage
SchemaKeys$new(uri = NULL, ctx = NULL, none_filter = FALSE)Arguments
uriOptional URI path to array for extracting its schema from. If not given, the default schema will be loaded.
ctxOptional tiledb_ctx object.
none_filterTRUEfor no filters,FALSEfor default filters. Applied on default schemas and not on schemas extracted from a URI path.