A virtual base class to be inherited by specialised R6 schema classes.
Provides common schema functionality for 'keys' and 'data' schemas for CAS storage. This class manages filter lists for coordinates, offsets, and validity data and controls tile capacity, cell order, and tile order settings.
The schema creation comes either from existing CAS storage URI path or the default templates.
This class should not be used directly.
Active bindings
coords_flistGet or set the filter list for the array's coordinates.
offsets_flistGet or set the filter list for the array's variable- length attribute offsets.
validity_flistGet or set the filter list for the array's validity.
capacityGet or set the array capacity of each tile.
cell_orderGet or set the cell order layout of the array.
tile_orderGet or set the tile order layout of the array.
Methods
SchemaBase$new()
Create a new SchemaBase object.
Usage
SchemaBase$new(uri = NULL, ctx = NULL, none_filter = FALSE)Arguments
uriOptional URI path to array for extracting its schema from. If not given, the default schema will be loaded.
ctxOptional tiledb_ctx object.
none_filterTRUEfor no filters,FALSEfor default filters. Applied on default schemas and not on schemas extracted from a URI path.