An R6 class that represents the 'data' schema for CAS storage and provides active fields to get/set filter lists for each dimension/attribute.
This class should not be used directly, but it can be accessed via driver_schemas().
Super class
SchemaBase -> SchemaData
Methods
Inherited methods
SchemaData$new()
Create a new SchemaData object.
Usage
SchemaData$new(uri = NULL, ctx = NULL, none_filter = FALSE)Arguments
uriOptional URI path to array for extracting its schema from. If not given, the default schema will be loaded.
ctxOptional tiledb_ctx object.
none_filterTRUEfor no filters,FALSEfor default filters. Applied on default schemas and not on schemas extracted from a URI path.