A class for working with Storr TileDB Fragments.
Active bindings
fob_keysRetrieve the R6.tiledb::TileDBFragments instance for
keysarray.fob_dataRetrieve the R6.tiledb::TileDBFragments instance for
dataarray.sizeReturn directory size.
Methods
Method new()
Create a new StorrFragments instance.
Usage
StorrFragments$new(uri, ctx = NULL)Arguments
uriURI path for TileDB Storr.
ctxOptional
tiledb::tiledb_ctx()object.
Method consolidate()
Consolidates the 'storr' fragments.
Consolidation in TileDB merges multiple array fragments into a single fragment to improve query performance by reducing the number of files that need to be read during queries.
The consolidation process is not deleting the old fragments.
To clear the consolidated fragments after the process, set
vacuum = TRUE which will invoke the vacuum process. Alternatively,
use the class method $vacuum().
Usage
StorrFragments$consolidate(what = c("all", "keys", "data"), cfg = NULL,
vacuum = FALSE, async = FALSE)Arguments
whatWhich array should be consolidated? Defaults to
"all"arrays.cfgA configuration object
tiledb::tiledb_config()to override context configuration. WhenNULL(default) the configuration parameters will be retrieved from object's context.vacuumShould the old fragments (consolidated) be deleted? Default is
FALSE.asyncShould it consolidate asynchronously? Default is
FALSE.
Returns
When async = FALSE, it returns TRUE for successful consolidation.
For async = TRUE, it returns a mirai::mirai() object immediately; once
resolved, it returns TRUE indicating consolidation success.
Method vacuum()
Vacuum Storr fragments
This operation deletes the old fragments (consolidated).
Usage
StorrFragments$vacuum(what = c("all", "keys", "data"), cfg = NULL,
async = FALSE)Arguments
whatWhich array to vacuum? Defaults to
"all"arrays.cfgA configuration object
tiledb::tiledb_config()to override context configuration. WhenNULL(default) the configuration parameters will be retrieved from object's context.asyncShould it vacuum asynchronously? Default is
FALSE.
Returns
When async = FALSE, it returns TRUE for successful vacuuming.
For async = TRUE, it returns a mirai::mirai() object immediately; once
resolved, it returns TRUE indicating vacuum success.