An R6 class that represents the storr's CAS schemas and provides access to both SchemaKeys and SchemaData objects.
Users can use the schema objects to access and modify individual schemas' filter lists and configuration via active fields.
For creating a TileDBDriverSchemas object, use the convenient wrapper
driver_schemas().
Active bindings
SchemaKeysGet
SchemaKeys()object.SchemaDataGet
SchemaData()object.
Methods
TileDBDriverSchemas$new()
Create a new TileDBDriverSchemas object.
Usage
TileDBDriverSchemas$new(uri = NULL, ctx = NULL, none_filter = FALSE)Arguments
uriOptional URI path to
TileDBdriver. If not given, the default schemas array will be used.ctxOptional tiledb_ctx object.
none_filterTRUEfor no filters,FALSEfor default filters. Applied on default schemas and not on schemas extracted from a URI path.