Functional interface that initialises a StorrFragments instance to work with TileDB Fragments.
Arguments
- uri
The URI path of storr.
- context
Optional tiledb_ctx object.
Details
The class includes fragment consolidation and vacuuming methods but also
provides access to TileDBFragments instances for keys and data arrays
where you can further inspect and manage the fragments for the specify arrays.
Class Methods Summary
For full definitions see the Methods section in StorrFragments.
Active Fields
fob_keys - TileDBFragments instance for the
keysarray.fob_data - TileDBFragments instance for the
dataarray.size - VFS directory size for the TileDB store.
Fragment Management
consolidate() - Consolidate fragments (options:
all,keys,data); supportsvacuumand sync/async modes.vacuum() - Remove old consolidated fragments (options:
all,keys,data); supports sync/async.reload_finfo() - Refresh fragment-info caches for both arrays.
Inspection
frag_num() - Total number of fragments (keys + data).
to_vacuum_num() - Number of fragments pending vacuum.
Examples
# URI path
uri <- tempfile()
sto <- storr_tiledb(uri, init = TRUE)
fosto <- storr_fragments(uri)
fosto$frag_num()
#> [1] 0